@@ -1,11 +1,22 @@
+from reasoner_pydantic.shared import CURIE
 from typing import Dict, List, Optional
 
 from pydantic import BaseModel, conlist
 from reasoner_pydantic import BiolinkEntity, BiolinkPredicate
 
 
+class MetaAttribute(BaseModel):
+    """MetaAttribute."""
+    attribute_type_id: CURIE
+    attribute_source: Optional[str]
+    original_attribute_names: Optional[List[str]]
+    constraint_use: Optional[bool] = False
+    constraint_name: Optional[str]
+
+
 class MetaNode(BaseModel):
     id_prefixes: conlist(str, min_items=1)
+    attributes: Optional[List[MetaAttribute]]
 
     class Config:
         extra = 'forbid'
@@ -15,7 +26,7 @@ class MetaEdge(BaseModel):
     subject: BiolinkEntity
     predicate: BiolinkPredicate
     object: BiolinkEntity
-    relations: Optional[List[str]]
+    attributes: Optional[List[MetaAttribute]]
 
     class Config:
         extra = 'forbid'
